searchNodes=[{"doc":"Sorts a list of maps per a list of sort specs . Also supports: keywords structs implementing the Access behaviour nested maps, keywords or structs implementing the Access behaviour","ref":"MapSorter.html","title":"MapSorter","type":"module"},{"doc":"Sorts maps per the given sort specs (compile time or runtime). Examples of sort specs for flat data structures: - implicit : [ :dob , :name ] - mixed : [ :dob , desc : :name ] - explicit : [ asc : :dob , desc : :name ] Examples of sort specs with a Date key for flat data structures: - implicit : [ { :dob Date } , :name ] - mixed : [ { :dob Date } , desc : :name ] - explicit : [ asc : { :dob Date } , desc : :name ] Examples of sort specs for nested data structures: - implicit : [ [ :birth , :date ] , :name ] - mixed : [ [ :birth , :date ] , desc : :name ] - explicit : [ asc : [ :birth , :date ] , desc : :name ] Examples of sort specs with a Date key for nested data structures: - implicit : [ { [ :birth , :date ] , Date } , :name ] - mixed : [ { [ :birth , :date ] , Date } , desc : :name ] - explicit : [ asc : { [ :birth , :date ] , Date } , desc : :name ] Examples iex&gt; require MapSorter iex&gt; people = [ ...&gt; %{ name : &quot;Mike&quot; , likes : &quot;movies&quot; , dob : &quot;1992-04-15&quot; } , ...&gt; %{ name : &quot;Mary&quot; , likes : &quot;travels&quot; , dob : &quot;1992-04-15&quot; } , ...&gt; %{ name : &quot;Bill&quot; , likes : &quot;karate&quot; , dob : &quot;1977-08-28&quot; } , ...&gt; %{ name : &quot;Joe&quot; , likes : &quot;boxing&quot; , dob : &quot;1977-08-28&quot; } , ...&gt; %{ name : &quot;Jill&quot; , likes : &quot;cooking&quot; , dob : &quot;1976-09-28&quot; } ...&gt; ] iex&gt; sort_specs = Tuple . to_list ( { :dob , { :desc , :likes } } ) iex&gt; sorted_people = %{ ...&gt; explicit : MapSorter . sort ( people , asc : :dob , desc : :likes ) , ...&gt; mixed : MapSorter . sort ( people , [ :dob , desc : :likes ] ) , ...&gt; runtime : MapSorter . sort ( people , sort_specs ) ...&gt; } iex&gt; sorted_people . explicit == sorted_people . mixed and ...&gt; sorted_people . explicit == sorted_people . runtime and ...&gt; sorted_people . explicit [ %{ name : &quot;Jill&quot; , likes : &quot;cooking&quot; , dob : &quot;1976-09-28&quot; } , %{ name : &quot;Bill&quot; , likes : &quot;karate&quot; , dob : &quot;1977-08-28&quot; } , %{ name : &quot;Joe&quot; , likes : &quot;boxing&quot; , dob : &quot;1977-08-28&quot; } , %{ name : &quot;Mary&quot; , likes : &quot;travels&quot; , dob : &quot;1992-04-15&quot; } , %{ name : &quot;Mike&quot; , likes : &quot;movies&quot; , dob : &quot;1992-04-15&quot; } ]","ref":"MapSorter.html#sort/2","title":"MapSorter.sort/2","type":"macro"},{"doc":"Generates a compare function from a list of sort specs .","ref":"MapSorter.Compare.html","title":"MapSorter.Compare","type":"module"},{"doc":"Generates a compare function from a list of sort specs . Examples iex&gt; alias MapSorter.Compare iex&gt; sort_specs = [ :dob , desc : :likes ] iex&gt; fun = Compare . fun ( sort_specs ) iex&gt; is_function ( fun , 2 ) true","ref":"MapSorter.Compare.html#fun/1","title":"MapSorter.Compare.fun/1","type":"function"},{"doc":"Generates a compare function as a heredoc from a list of sort specs . Examples iex&gt; alias MapSorter.Compare iex&gt; Compare . heredoc ( [ ] ) &quot;&quot;&quot; &amp; cond do true -&gt; true or &amp;1 * &amp;2 end &quot;&quot;&quot; iex&gt; alias MapSorter.Compare iex&gt; sort_specs = [ :name , { :desc , :dob } ] iex&gt; Compare . heredoc ( sort_specs ) &quot;&quot;&quot; &amp; cond do &amp;1[:name] &lt; &amp;2[:name] -&gt; true &amp;1[:name] &gt; &amp;2[:name] -&gt; false &amp;1[:dob] &gt; &amp;2[:dob] -&gt; true &amp;1[:dob] &lt; &amp;2[:dob] -&gt; false true -&gt; true or &amp;1 * &amp;2 end &quot;&quot;&quot; iex&gt; alias MapSorter.Compare iex&gt; sort_specs = [ :name , { :desc , { :dob , Date } } ] iex&gt; Compare . heredoc ( sort_specs ) &quot;&quot;&quot; &amp; cond do &amp;1[:name] &lt; &amp;2[:name] -&gt; true &amp;1[:name] &gt; &amp;2[:name] -&gt; false &amp;1[:dob] != nil and Date.compare(&amp;1[:dob], &amp;2[:dob]) == :gt -&gt; true &amp;1[:dob] != nil and Date.compare(&amp;1[:dob], &amp;2[:dob]) == :lt -&gt; false true -&gt; true or &amp;1 * &amp;2 end &quot;&quot;&quot;","ref":"MapSorter.Compare.html#heredoc/1","title":"MapSorter.Compare.heredoc/1","type":"function"},{"doc":"","ref":"MapSorter.Compare.html#t:fun/0","title":"MapSorter.Compare.fun/0","type":"type"},{"doc":"Generates cond clauses as a heredoc from a list of sort specs .","ref":"MapSorter.Cond.html","title":"MapSorter.Cond","type":"module"},{"doc":"Generates cond clauses as a heredoc from a list of sort specs . Examples iex&gt; alias MapSorter.Cond iex&gt; sort_specs = [ :name , { :desc , :dob } ] iex&gt; Cond . clauses ( sort_specs ) &quot;&quot;&quot; &amp;1[:name] &lt; &amp;2[:name] -&gt; true &amp;1[:name] &gt; &amp;2[:name] -&gt; false &amp;1[:dob] &gt; &amp;2[:dob] -&gt; true &amp;1[:dob] &lt; &amp;2[:dob] -&gt; false &quot;&quot;&quot; iex&gt; alias MapSorter.Cond iex&gt; sort_specs = [ :name , { :desc , { :dob , Date } } ] iex&gt; Cond . clauses ( sort_specs ) &quot;&quot;&quot; &amp;1[:name] &lt; &amp;2[:name] -&gt; true &amp;1[:name] &gt; &amp;2[:name] -&gt; false &amp;1[:dob] != nil and Date.compare(&amp;1[:dob], &amp;2[:dob]) == :gt -&gt; true &amp;1[:dob] != nil and Date.compare(&amp;1[:dob], &amp;2[:dob]) == :lt -&gt; false &quot;&quot;&quot;","ref":"MapSorter.Cond.html#clauses/1","title":"MapSorter.Cond.clauses/1","type":"function"},{"doc":"Generates index brackets as a string from a sort spec key .","ref":"MapSorter.Container.html","title":"MapSorter.Container","type":"module"},{"doc":"Generates index brackets as a string from a sort spec key . Examples iex&gt; import MapSorter.Container , only : [ brackets : 1 ] iex&gt; brackets ( [ :birth , :date ] ) &quot;[:birth][:date]&quot; iex&gt; import MapSorter.Container , only : [ brackets : 1 ] iex&gt; brackets ( [ :address , &#39;city&#39; , :state ] ) &quot;[:address][&#39;city&#39;][:state]&quot; iex&gt; import MapSorter.Container , only : [ brackets : 1 ] iex&gt; brackets ( [ :dob ] ) &quot;[:dob]&quot; iex&gt; import MapSorter.Container , only : [ brackets : 1 ] iex&gt; brackets ( :dob ) &quot;[:dob]&quot; iex&gt; import MapSorter.Container , only : [ brackets : 1 ] iex&gt; brackets ( &#39;dob&#39; ) &quot;[&#39;dob&#39;]&quot;","ref":"MapSorter.Container.html#brackets/1","title":"MapSorter.Container.brackets/1","type":"function"},{"doc":"","ref":"MapSorter.Log.html","title":"MapSorter.Log","type":"module"},{"doc":"","ref":"MapSorter.Log.html#debug/2","title":"MapSorter.Log.debug/2","type":"function"},{"doc":"","ref":"MapSorter.Log.html#error/2","title":"MapSorter.Log.error/2","type":"function"},{"doc":"","ref":"MapSorter.Regex.html","title":"MapSorter.Regex","type":"module"},{"doc":"Compares two regex structs.","ref":"MapSorter.Regex.html#compare/2","title":"MapSorter.Regex.compare/2","type":"function"},{"doc":"Defines the sort spec types.","ref":"MapSorter.SortSpec.html","title":"MapSorter.SortSpec","type":"module"},{"doc":"","ref":"MapSorter.SortSpec.html#t:key/0","title":"MapSorter.SortSpec.key/0","type":"type"},{"doc":"","ref":"MapSorter.SortSpec.html#t:sort_dir/0","title":"MapSorter.SortSpec.sort_dir/0","type":"type"},{"doc":"","ref":"MapSorter.SortSpec.html#t:t/0","title":"MapSorter.SortSpec.t/0","type":"type"},{"doc":"Generates the AST of a compare function from a list of sort specs .","ref":"MapSorter.SortSpecs.html","title":"MapSorter.SortSpecs","type":"module"},{"doc":"Converts sort specs into the AST of a compare function (compile time or runtime). Examples iex&gt; alias MapSorter.SortSpecs iex&gt; sort_specs = [ :dob , desc : :likes ] iex&gt; { :ok , comp_fun_ast } = SortSpecs . to_quoted ( sort_specs ) iex&gt; { :&amp; , _meta , [ args ] } = comp_fun_ast iex&gt; Macro . to_string ( args ) &quot;&quot;&quot; cond do (&amp;1)[:dob] &lt; (&amp;2)[:dob] -&gt; true (&amp;1)[:dob] &gt; (&amp;2)[:dob] -&gt; false (&amp;1)[:likes] &gt; (&amp;2)[:likes] -&gt; true (&amp;1)[:likes] &lt; (&amp;2)[:likes] -&gt; false true -&gt; true or &amp;1 * &amp;2 end &quot;&quot;&quot; |&gt; String . trim_trailing ( ) iex&gt; alias MapSorter.SortSpecs iex&gt; sort_specs = quote do : Tuple . to_list ( { :dob , { :desc , :likes } } ) iex&gt; { :ok , comp_fun_ast } = SortSpecs . to_quoted ( sort_specs ) iex&gt; { { :. , _ , _ } , _meta , [ args ] } = comp_fun_ast iex&gt; Macro . to_string ( args ) &quot;Tuple.to_list({:dob, {:desc, :likes}})&quot;","ref":"MapSorter.SortSpecs.html#to_quoted/1","title":"MapSorter.SortSpecs.to_quoted/1","type":"function"},{"doc":"","ref":"MapSorter.SortSpecs.html#t:t/0","title":"MapSorter.SortSpecs.t/0","type":"type"},{"doc":"","ref":"MapSorter.Version.html","title":"MapSorter.Version","type":"module"},{"doc":"Compares two version structs.","ref":"MapSorter.Version.html#compare/2","title":"MapSorter.Version.compare/2","type":"function"}]